==> cpg1.4.x_plugin_jupload_v3.5.1.zip: jupload/page/log_error.php <==
<?php
/*
 *******************************************
 plugin JUpload for Coppermine Photo Gallery
 *******************************************

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 ********************************************
 $Revision: 185 $
 $Author: etienne_sf $
 $Date: 2008-03-12 20:26:16 +0100 (mer., 12 mars 2008) $
 ********************************************
 *
 * Allows easy upload to the gallery, through a java applet. 
 * 
 * Up to date version of this script can be retrieved with the full JUpload package, here:
 * 
 * http://etienne.sf.free.fr/wiki
 * 
 * Directly here:
 * http://etienne.sf.free.fr/wiki/doku.php?id=jupload_coppermine_download_gb
 * 
 * Support is available on this forum:
 * http://coppermine-gallery.net/forum/index.php?topic=43432
 * 
 * The applet is published on sourceforge:
 * http://jupload.sourceforge.net
 * 
 */
 

if (!defined('IN_COPPERMINE')) { die('Not in Coppermine...');}
if (!defined('JUPLOAD_PHP')) { die('Not in Jupload...');}


//####################################################################################################
//#################################     INCLUDES    ##################################################
//####################################################################################################

//Let's also include the upload text.
define('UPLOAD_PHP', true);
define('DB_INPUT_PHP', true);
define('ADMIN_PHP', true);

// Specific includes
require('include/phpmailer.lang-en.php');
echo("100\r\n");
require('include/mailer.inc.php');
echo("200\r\n");
require('include/picmgmt.inc.php');
echo("300\r\n");


//####################################################################################################
//################################# MAIN CODE BLOCK ##################################################
//####################################################################################################

//This script should only be called by the JUpload applet. This means that the current user has upload 
//authorization. If not, someone is trying to spam the admin. 
//USER_CAN_CREATE_ALBUMS: seems to indicate that the user may have its personnal gallery (at least for the admin)
if (!USER_CAN_UPLOAD_PICTURES && !USER_CAN_CREATE_ALBUMS) {
	$msg = str_replace('$1', 'login.php?referer=plugins/jupload/jupload.php', $lang_jupload_php['perm_denied']);

	cpg_die(ERROR, $msg, __FILE__, __LINE__);
}
//Get  parameters.
$description	= isset($_POST['description']	) ? $_POST['description'] 	: '';
$log		 	= isset($_POST['debugOutput']	) ? $_POST['debugOutput']	: '';

//Set local variables, from coppermine configuration
$url_parsed		= parse_url($CONFIG['site_url']);
$to				=  $CONFIG['gallery_admin_email'];  /* for cpg_mail : 'admin'; */
$from			= $CONFIG['gallery_admin_email'];
$user_desc		= ($USER_DATA['user_email'] == '')  ?
						'no user information'
						: "mail: $USER_NAME (${USER_DATA['user_email']})"
						;  

$headers		= "From: $from\r\n" .
					"Content-type: text/plain\r\n";
$subject		= "[log_error]$description";
$body			= "An error occured in JUpload applet, for the user ${USER_DATA['user_name']} ($user_desc)."
					. "\n\nHere is the debug output for his session within the applet:\n\n"
					.str_replace("\n", "\r\n", $log);
/*
echo ("to: $to\n");
echo ("from: $from\n");
echo ("description: $description\n") ;
echo ("body: $log\n") ;
*/

//Let's send the mail.


/*

The following lines don't work, because cpg_mail seems to be able to instanciate its language strings,
when called fro here !

:-(

echo("Avant cpg_mail($to, $subject, body, 'text/plain', 'jupload', $from)\n");

$return = cpg_mail ($to, $subject, $body, 'text/plain', 'jupload', $from);
echo("Retour de cpg_mail: $return\n");
if ($return == 'Mail sent!') {
	echo("SUCCESS\n");
} else if ($return == ""){
	log_write("$body\r\n$return");
	echo("ERROR: cpg_mail returned an empty string !\n");
} else {
	log_write("$body\r\n$return");
	echo("ERROR: Error in Coppermine's cpg_mail ($return)\n");	
}
*/


// If we got there, we must, at least, log the error 
// (see the applet tag in upload_page.php)
log_write("$subject\r\n$body\r\n", 'jupload');

// Then, maybe we should send a mail.
if ($JUPLOAD_CONFIG[JUPLOAD_CONFIG_onError] == JUPLOAD_CONFIG_onError_mailAdmin) {
	echo("Avant mail($to, $subject, body, $headers)\n");
	
	if (mail($to, $subject, $body, $headers)) {
		echo "SUCCESS\r\n";
	} else {
		//To bad, it's an error.
		if ($php_errormsg == '') {
			echo "ERROR: Error while sending the mail (php_errormsg is empty, put the php ini parameter track_errors to on for more information).\r\n";
		} else {
			echo "ERROR: Error while sending the mail (php_errormsg: $php_errormsg).\r\n";
		} 
	}
} else {
	echo("WARNING: No action\r\n");
	echo("SUCCESS\r\n");
}

==> cpg1.5.x_plugin_jupload_v4.0.0_rc3.zip: jupload/page/log_error.php <==
<?php
/*
 *******************************************
 plugin JUpload for Coppermine Photo Gallery
 *******************************************

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 ********************************************
 $Revision: 185 $
 $Author: etienne_sf $
 $Date: 2008-03-12 20:26:16 +0100 (mer., 12 mars 2008) $
 ********************************************
 *
 * Allows easy upload to the gallery, through a java applet. 
 * 
 * Up to date version of this script can be retrieved with the full JUpload package, here:
 * 
 * http://etienne.sf.free.fr/wiki
 * 
 * Directly here:
 * http://forum.coppermine-gallery.net/index.php/board,100.0.html
 * 
 * Support is available on this forum:
 * http://coppermine-gallery.net/forum/index.php?topic=43432
 * 
 * The applet is published on sourceforge:
 * http://jupload.sourceforge.net
 * 
 */
 

if (!defined('IN_COPPERMINE')) { die('Not in Coppermine...');}
if (!defined('JUPLOAD_PHP')) { die('Not in Jupload...');}


//####################################################################################################
//#################################     INCLUDES    ##################################################
//####################################################################################################

//Let's also include the upload text.
define('UPLOAD_PHP', true);
define('DB_INPUT_PHP', true);
define('ADMIN_PHP', true);

// Specific includes
require('include/phpmailer.lang-en.php');
echo("100\r\n");
require('include/mailer.inc.php');
echo("200\r\n");
require('include/picmgmt.inc.php');
echo("300\r\n");


//####################################################################################################
//################################# MAIN CODE BLOCK ##################################################
//####################################################################################################

//This script should only be called by the JUpload applet. This means that the current user has upload 
//authorization. If not, someone is trying to spam the admin. 
//USER_CAN_CREATE_ALBUMS: seems to indicate that the user may have its personnal gallery (at least for the admin)
if (!USER_CAN_UPLOAD_PICTURES && !USER_CAN_CREATE_ALBUMS) {
	$msg = str_replace('$1', 'login.php?referer=plugins/jupload/jupload.php', $lang_jupload_php['perm_denied']);

	cpg_die(ERROR, $msg, __FILE__, __LINE__);
}
//Get  parameters.
$description	= isset($_POST['description']	) ? $_POST['description'] 	: '';
$log		 	= isset($_POST['debugOutput']	) ? $_POST['debugOutput']	: '';

//Set local variables, from coppermine configuration
$url_parsed		= parse_url($CONFIG['site_url']);
$to				=  $CONFIG['gallery_admin_email'];  /* for cpg_mail : 'admin'; */
$from			= $CONFIG['gallery_admin_email'];
$user_desc		= ($USER_DATA['user_email'] == '')  ?
						'no user information'
						: "mail: $USER_NAME (${USER_DATA['user_email']})"
						;  

$headers		= "From: $from\r\n" .
					"Content-type: text/plain\r\n";
$subject		= "[log_error]$description";
$body			= "An error occured in JUpload applet, for the user ${USER_DATA['user_name']} ($user_desc)."
					. "\n\nHere is the debug output for his session within the applet:\n\n"
					.str_replace("\n", "\r\n", $log);
/*
echo ("to: $to\n");
echo ("from: $from\n");
echo ("description: $description\n") ;
echo ("body: $log\n") ;
*/

//Let's send the mail.


/*

The following lines don't work, because cpg_mail seems to be able to instanciate its language strings,
when called fro here !

:-(

echo("Avant cpg_mail($to, $subject, body, 'text/plain', 'jupload', $from)\n");

$return = cpg_mail ($to, $subject, $body, 'text/plain', 'jupload', $from);
echo("Retour de cpg_mail: $return\n");
if ($return == 'Mail sent!') {
	echo("SUCCESS\n");
} else if ($return == ""){
	log_write("$body\r\n$return");
	echo("ERROR: cpg_mail returned an empty string !\n");
} else {
	log_write("$body\r\n$return");
	echo("ERROR: Error in Coppermine's cpg_mail ($return)\n");	
}
*/


// If we got there, we must, at least, log the error 
// (see the applet tag in upload_page.php)
log_write("$subject\r\n$body\r\n", 'jupload');

// Then, maybe we should send a mail.
if ($JUPLOAD_CONFIG[JUPLOAD_CONFIG_onError] == JUPLOAD_CONFIG_onError_mailAdmin) {
	echo("Avant mail($to, $subject, body, $headers)\n");
	
	if (mail($to, $subject, $body, $headers)) {
		echo "SUCCESS\r\n";
	} else {
		//To bad, it's an error.
		if ($php_errormsg == '') {
			echo "ERROR: Error while sending the mail (php_errormsg is empty, put the php ini parameter track_errors to on for more information).\r\n";
		} else {
			echo "ERROR: Error while sending the mail (php_errormsg: $php_errormsg).\r\n";
		} 
	}
} else {
	echo("WARNING: No action\r\n");
	echo("SUCCESS\r\n");
}
